@@ -1,5 +1,5 @@
 bayesmbc<-function(G,Z,prior,Z.K.ref=NULL,sample.size=2000,interval=10,burnin=500,verbose=FALSE){
-  start<-find.clusters(G,Z)
+  start<-mbc.VII.EM(G,Z)
   state<-start<-with(start,list(Z=Z,
                                 Z.mean=Z.mean,
                                 Z.var=Z.var,
@@ -22,15 +22,16 @@ bayesmbc<-function(G,Z,prior,Z.K.ref=NULL,sample.size=2000,interval=10,burnin=50
                        list(Z.mean=apply(Z.mean,2:3,mean),
                             Z.var=apply(Z.var,2,mean),
                             Z.K=apply(Z.K,2,function(x)which.max(tabulate(x,G))),
-                            Z.pZK=t(apply(Z.K,2,function(x)tabulate(x,G)/length(x)))
+                            Z.pZK=t(apply(Z.K,2,function(x)tabulate(x,G)/length(x))),
+                            Z.pK=tabulate(c(Z.K),G)/length(Z.K)
                             )
                        )
   mcmc.out
 }
 
 bayesmbc.snowFT<-function(threads,G,Z,prior,Z.K.ref=NULL,sample.size=2000,interval=10,burnin=500,verbose=FALSE){
-  require(snowFT)
-  start<-find.clusters(G,Z)
+  if(!require(snowFT)) stop("Package 'snowFT' required for multithreaded model based clustering MCMC.")
+  start<-mbc.VII.EM(G,Z)
   state<-start<-with(start,list(Z=Z,
                                 Z.mean=Z.mean,
                                 Z.var=Z.var,
@@ -53,7 +54,8 @@ bayesmbc.snowFT<-function(threads,G,Z,prior,Z.K.ref=NULL,sample.size=2000,interv
                        list(Z.mean=apply(Z.mean,2:3,mean),
                             Z.var=apply(Z.var,2,mean),
                             Z.K=apply(Z.K,2,function(x)which.max(tabulate(x,G))),
-                            Z.pZK=t(apply(Z.K,2,function(x)tabulate(x,G)/length(x)))
+                            Z.pZK=t(apply(Z.K,2,function(x)tabulate(x,G)/length(x))),
+                            Z.pK=tabulate(c(Z.K),G)/length(Z.K)
                             )
                        )
   mcmc.out
