@@ -118,9 +118,6 @@ add.mcmc.mle.mle.ergmm<-function(x,Z.ref=best.avail.Z.ref.ergmm(x)){
   x[["mle"]]<-scale(x[["model"]],x[["mle"]])
 
   if(x[["model"]][["d"]] && "rotation" %in% latent.effect.invariances[[x[["model"]][["familyID"]]]]){
-    if(!require(shapes,quietly=TRUE)){
-      stop("You need the 'shapes' package to summarize the fit of latent cluster models.")
-    }
     x[["mle"]][["Z"]]<-procOPA(x[["model"]],Z.ref,x[["mle"]][["Z"]])[["Bhat"]]
   }
   
@@ -155,9 +152,6 @@ add.mcmc.pmode.pmode.ergmm<-function(x,Z.ref=best.avail.Z.ref.ergmm(x)){
     
   if(x[["model"]][["d"]]>0 && !is.null(x[["pmode"]])){
     x[["pmode"]]<-scale(x[["model"]], x[["pmode"]])
-    if(!require(shapes,quietly=TRUE)){
-      stop("You need the 'shapes' package to summarize the fit of latent cluster models.")
-    }
     P<-procOPA(x[["model"]],Z.ref,x[["pmode"]][["Z"]])[["R"]]
     x[["pmode"]][["Z"]]<-x[["pmode"]][["Z"]]%*%P
     if(!is.null(x[["pmode"]][["Z.mean"]]))
@@ -172,7 +166,7 @@ find.pmode.loop<-function(model,start,prior,control){
     if(control[["verbose"]]>1) cat(i,"")
     pmode.old<-pmode
     pmode<-find.mpe(model,pmode,prior=prior,given=list(Z.K=pmode[["Z.K"]]),control=control)
-    if(model[["G"]]>1) pmode[["Z.K"]]<-find.clusters(model[["G"]],pmode[["Z"]])[["Z.K"]]
+    if(model[["G"]]>1) pmode[["Z.K"]]<-mbc.VII.EM(model[["G"]],pmode[["Z"]],resume=list(Z.mean=pmode[["Z.mean"]],Z.var=pmode[["Z.var"]],Z.pK=pmode[["Z.pK"]]))[["Z.K"]]
     if(all.equal(pmode.old,pmode)[1]==TRUE) break
   }
   pmode
@@ -182,9 +176,6 @@ add.mkl.pos.ergmm<-function(x, Z.ref=best.avail.Z.ref.ergmm(x)){
   if(!is.null(x[["sample"]])){
     if(x[["control"]][["verbose"]]) cat("Fitting the MKL locations... ")
     x[["mkl"]]<-find.mkl(x[["model"]],x[["sample"]],x[["control"]])
-    if(!require(shapes,quietly=TRUE)){
-      stop("You need the 'shapes' package to summarize the fit of latent cluster models.")
-    }
   }
   if(!is.null(x[["mkl"]][["Z"]])) x[["mkl"]]<-scale(x[["model"]],x[["mkl"]])
   if(!is.null(x[["mkl"]][["Z"]])) x[["mkl"]][["Z"]]<-procOPA(x[["model"]],Z.ref,x[["mkl"]][["Z"]])[["Bhat"]]
@@ -204,7 +195,6 @@ proc.sample.ergmm<-function(x,Z.ref=best.avail.Z.ref.ergmm(x)){
 labelswitch.sample.ergmm<-function(x,Z.K.ref=best.avail.Z.K.ref.ergmm(x)){
   if(!is.null(x[["sample"]]) && x[["model"]][["G"]]>1){
     if(x[["control"]][["verbose"]]) cat("Performing label-switching... ")
-    require(mclust,quiet=TRUE)
     Q.start<-switch.Q.K(Z.K.ref,x[["model"]][["G"]])
     x[["sample"]] <- {
       if(x[["control"]][["kl.threads"]]==1)
@@ -239,7 +229,7 @@ best.avail.Z.K.ref.ergmm<-function(x){
   if(!is.null(x[["mcmc.pmode"]][["Z.K"]])) return(x[["mcmc.pmode"]][["Z.K"]])
   if(!is.null(x[["start"]][["Z.K"]])) return(x[["start"]][["Z.K"]])
   
-  return(find.clusters(x[["model"]][["G"]],best.avail.Z.ref.ergmm(x))[["Z.K"]])
+  return(mbc.VII.EM(x[["model"]][["G"]],best.avail.Z.ref.ergmm(x))[["Z.K"]])
 }
 
 # We are overriding the generic for "scale" to make it more flexible.
